# App description

* bloxroute-gateway connects you to the BDN, a blockchain distribution network, to greatly speed up block propagation
times and scale your blockchain today.

* [bloxroute-cli] is also included.

# Documentation
You can find our full documentation, including requirements and installation instructions, [on our website][documentation].

# Troubleshooting

Contact us at support@bloxroute.com for further questions.

[documentation]: https://docs.bloxroute.com/
[bloxroute-cli]: https://pypi.org/project/bloxroute-cli/
